/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.spring;

import java.util.Properties;

import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;

/**
 * Bean that provides postprocessing of the bean factory based on a given set of
 * properties.
 * 
 * @author Erik Brakkee
 */
class PropertySetter extends PropertyPlaceholderConfigurer {
    /**
     * Constructs the property setter.
     * 
     * @param aProps
     *            Properties.
     */
    public PropertySetter(Properties aProps) {
        String propFile = createPropertyFile(aProps);
        setLocation(new StringResource(propFile));
    }

    public static String createPropertyFile(Properties aProps) {
        StringBuffer buf = new StringBuffer();

        for (Object key : aProps.keySet()) {
            buf.append(key);
            buf.append("=");
            buf.append(aProps.get(key));
            buf.append("\n");
        }

        return buf.toString();
    }
}
